@@ -1,6 +1,6 @@
 /*
     KMetronome - ALSA Sequencer based MIDI metronome
-    Copyright (C) 2006-2014, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,9 +12,8 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "drumgridmodel.h"
@@ -28,7 +27,7 @@ DrumGridModel::DrumGridModel(QObject *parent)
     m_columns(PATTERN_COLUMNS),
     m_figure(PATTERN_FIGURE),
     m_lastValue(DEFVAL),
-    m_insList(NULL)
+    m_insList(nullptr)
 {
     m_modelData.clear();
     m_keys.clear();
@@ -41,7 +40,7 @@ void DrumGridModel::setInstrumentList(InstrumentList* instruments)
 
 void DrumGridModel::loadKeyNames(const QString& instrument, int bank, int patch)
 {
-    if (m_insList != NULL) {
+    if (m_insList != nullptr) {
         Instrument ins = m_insList->value(instrument);
         const InstrumentData& notes = ins.notes(bank, patch);
         InstrumentData::ConstIterator k;
