@@ -1,6 +1,6 @@
 /*
     KMetronome - ALSA Sequencer based MIDI metronome
-    Copyright (C) 2006-2020, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,7 +27,8 @@
 namespace  IconUtils
 {
     void PaintPixmap(QPixmap &pixmap, const QColor& color);
-    QPixmap GetPixmap(QWidget* widget, const QString& fileName);
+    QPixmap GetPixmap(const QString& fileName);
+    QIcon GetIcon(const QString& name, bool forcedTheme = false);
     void SetLabelIcon(QLabel *label, const QString& fileName);
     void SetupComboFigures(QComboBox *combo);
     void SetWindowIcon(QWidget *widget);
