@@ -1,6 +1,6 @@
 /***************************************************************************
  *   KMetronome - ALSA Sequencer based MIDI metronome                      *
- *   Copyright (C) 2005-2020 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
+ *   Copyright (C) 2005-2021 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -19,6 +19,7 @@
 #include <cmath>
 #include <QEvent>
 #include <QLabel>
+#include <QActionGroup>
 #include <QStandardPaths>
 #include <QMessageBox>
 #include <QSettings>
@@ -47,7 +48,12 @@ static QString dataDirectory()
     if (test.exists()) {
         return test.absolutePath();
     }
-    QStringList candidates = QStandardPaths::standardLocations(QStandardPaths::DataLocation);
+    QStringList candidates =
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
+        QStandardPaths::standardLocations(QStandardPaths::DataLocation);
+#else
+        QStandardPaths::standardLocations(QStandardPaths::AppLocalDataLocation);
+#endif
     foreach(const QString& d, candidates) {
         test = QDir(d);
         if (test.exists()) {
@@ -63,7 +69,7 @@ static QString trDirectory()
     return QLatin1String(":/");
 #else
     QDir test(dataDirectory() + "/translations/");
-    qDebug() << test.absolutePath();
+    //qDebug() << test.absolutePath();
     if (test.exists()) {
         return test.absolutePath();
     }
@@ -75,8 +81,9 @@ static QString trQtDirectory()
 {
 #if defined(TRANSLATIONS_EMBEDDED)
     return QLatin1String(":/");
-#endif
+#else
     return QLibraryInfo::location(QLibraryInfo::TranslationsPath);
+#endif
 }
 
 KMetronome::KMetronome(QWidget *parent) :
@@ -94,7 +101,7 @@ KMetronome::KMetronome(QWidget *parent) :
     m_trp = new QTranslator(this);
     QCoreApplication::installTranslator(m_trp);
     QLocale locale(configuredLanguage());
-    qDebug() << "locale:" << locale << "path:" << trDirectory();
+    //qDebug() << "locale:" << locale << "path:" << trDirectory();
     if (!m_trq->load(locale, QLatin1String("qt"), QLatin1String("_"), trQtDirectory())) {
         qWarning() << "Failure loading Qt5 translations for" << configuredLanguage();
     }
@@ -128,23 +135,22 @@ KMetronome::KMetronome(QWidget *parent) :
     m_ui.m_air->setCurrentIndex(4);
 
     IconUtils::SetupComboFigures(m_ui.m_figure);
-    IconUtils::SetWindowIcon(this);
 
-    connect( m_ui.m_exitbtn, SIGNAL(clicked()), SLOT(close()) );
-    connect( m_ui.m_configbtn, SIGNAL(clicked()), SLOT(optionsPreferences()) );
-    connect( m_ui.m_patternbtn, SIGNAL(clicked()), SLOT(editPatterns()) );
-    connect( m_ui.m_playbtn, SIGNAL(clicked()), SLOT(play()) );
-    connect( m_ui.m_stopbtn, SIGNAL(clicked()), SLOT(stop()) );
-    connect( m_ui.m_beatsBar, SIGNAL(valueChanged(int)), SLOT(beatsBarChanged(int)) );
-    connect( m_ui.m_figure, SIGNAL(activated(int)), SLOT(rhythmFigureChanged(int)) );
-    connect( m_ui.m_tempo, SIGNAL(valueChanged(int)), SLOT(tempoChanged(int)) );
-    connect( m_ui.m_dial1, SIGNAL(valueChanged(int)), SLOT(weakVeloChanged(int)) );
-    connect( m_ui.m_dial2, SIGNAL(valueChanged(int)), SLOT(strongVeloChanged(int)) );
-    connect( m_ui.m_dial3, SIGNAL(valueChanged(int)), SLOT(volumeChanged(int)) );
-    connect( m_ui.m_dial4, SIGNAL(valueChanged(int)), SLOT(balanceChanged(int)) );
-    connect( m_ui.m_air, SIGNAL(activated(int)), SLOT(tempoComboChanged(int)) );
-    connect( m_ui.m_tempo, SIGNAL(valueChanged(int)), SLOT(displayTempo(int)) );
-    connect( m_ui.m_pattern, SIGNAL(activated(int)), SLOT(patternChanged(int)) );
+    connect( m_ui.m_exitbtn, &QAbstractButton::clicked, this, &QWidget::close );
+    connect( m_ui.m_configbtn, &QAbstractButton::clicked, this, &KMetronome::optionsPreferences );
+    connect( m_ui.m_patternbtn, &QAbstractButton::clicked, this, &KMetronome::editPatterns );
+    connect( m_ui.m_playbtn, &QAbstractButton::clicked, this, &KMetronome::play );
+    connect( m_ui.m_stopbtn, &QAbstractButton::clicked, this, &KMetronome::stop );
+    connect( m_ui.m_beatsBar, QOverload<int>::of(&QSpinBox::valueChanged), this, &KMetronome::beatsBarChanged );
+    connect( m_ui.m_figure, QOverload<int>::of(&QComboBox::activated), this, &KMetronome::rhythmFigureChanged );
+    connect( m_ui.m_tempo, &QAbstractSlider::valueChanged, this, &KMetronome::tempoChanged );
+    connect( m_ui.m_dial1, &QAbstractSlider::valueChanged, this, &KMetronome::weakVeloChanged );
+    connect( m_ui.m_dial2, &QAbstractSlider::valueChanged, this, &KMetronome::strongVeloChanged );
+    connect( m_ui.m_dial3, &QAbstractSlider::valueChanged, this, &KMetronome::volumeChanged );
+    connect( m_ui.m_dial4, &QAbstractSlider::valueChanged, this, &KMetronome::balanceChanged );
+    connect( m_ui.m_air, QOverload<int>::of(&QComboBox::activated), this, &KMetronome::tempoComboChanged );
+    connect( m_ui.m_tempo, &QAbstractSlider::valueChanged, this, &KMetronome::displayTempo );
+    connect( m_ui.m_pattern, QOverload<int>::of(&QComboBox::activated), this, &KMetronome::patternChanged );
 
     m_model = new DrumGridModel(this);
     m_instrumentList = new InstrumentList;
@@ -163,14 +169,15 @@ KMetronome::KMetronome(QWidget *parent) :
     try {
         m_seq = new SequencerAdapter(this);
         m_seq->setModel(m_model);
-        connect(m_seq, SIGNAL(signalUpdate(int,int)), this, SLOT(updateDisplay(int,int)), Qt::QueuedConnection);
-        connect(m_seq, SIGNAL(signalPlay()), this, SLOT(play()), Qt::QueuedConnection);
-        connect(m_seq, SIGNAL(signalStop()), this, SLOT(stop()), Qt::QueuedConnection);
-        connect(m_seq, SIGNAL(signalCont()), this, SLOT(cont()), Qt::QueuedConnection);
-        connect(m_seq, SIGNAL(signalNotation(int,int)), this, SLOT(setTimeSignature(int,int)), Qt::QueuedConnection);
+        connect(m_seq, &SequencerAdapter::signalUpdate, this, &KMetronome::updateDisplay, Qt::QueuedConnection);
+        connect(m_seq, &SequencerAdapter::signalPlay, this, &KMetronome::play, Qt::QueuedConnection);
+        connect(m_seq, &SequencerAdapter::signalStop, this, &KMetronome::stop, Qt::QueuedConnection);
+        connect(m_seq, &SequencerAdapter::signalCont, this, &KMetronome::cont, Qt::QueuedConnection);
+        connect(m_seq, &SequencerAdapter::signalNotation, this, &KMetronome::setTimeSignature, Qt::QueuedConnection);
         setupActions();
         readConfiguration();
         createLanguageMenu();
+        applyVisualStyle();
     } catch (drumstick::ALSA::SequencerError& ex) {
         QString errorstr = tr("Fatal error from the ALSA sequencer. "
             "This usually happens when the kernel doesn't have ALSA support, "
@@ -181,6 +188,8 @@ KMetronome::KMetronome(QWidget *parent) :
         QMessageBox::critical(nullptr, tr("Error"), errorstr);
         close();
     }
+    m_helpWindow = new HelpWindow(this);
+    m_helpWindow->applySettings();
 }
 
 KMetronome::~KMetronome()
@@ -191,7 +200,7 @@ KMetronome::~KMetronome()
 void KMetronome::setupActions()
 {
     m_ui.actionAboutQt->setIcon(QIcon(":/qt-project.org/qmessagebox/images/qtlogo-64.png"));
-    m_ui.actionAbout->setIcon(QIcon(IconUtils::GetPixmap(this, ":/icons/midi/icon32.png")));
+    m_ui.actionAbout->setIcon(QIcon(IconUtils::GetPixmap(":/icons/midi/icon32.png")));
     connect( m_ui.actionPlayStop, &QAction::triggered, this, &KMetronome::toggle );
     connect( m_ui.actionImportPatterns, &QAction::triggered, this, &KMetronome::slotImportPatterns );
     connect( m_ui.actionExportPatterns, &QAction::triggered, this, &KMetronome::slotExportPatterns );
@@ -218,7 +227,9 @@ void KMetronome::about()
 
 void KMetronome::help()
 {
-    HelpWindow::showPage(this, QStringLiteral("help/kmetronome.html"));
+    m_helpWindow->setIcons(m_internalIcons);
+    QString hname = QString("help/%1/index.html").arg(configuredLanguage());
+    m_helpWindow->showPage(hname);
 }
 
 void KMetronome::saveConfiguration()
@@ -230,6 +241,9 @@ void KMetronome::saveConfiguration()
     settings.setValue("language", m_language);
     settings.setValue("fakeToolbar", m_ui.actionShowActionButtons->isChecked());
     settings.setValue("toolbar", m_ui.actionShowToolbar->isChecked());
+    settings.setValue("qtstyle", m_style);
+    settings.setValue("darkMode", m_darkMode);
+    settings.setValue("internalIcons", m_internalIcons);
     if (m_seq != nullptr) {
         settings.setValue("instrument", m_instrument);
         settings.setValue("bank", m_bank);
@@ -299,6 +313,9 @@ void KMetronome::readConfiguration()
     int tempo = settings.value("tempo", 100).toInt();
     int ts_num = settings.value("rhythmNumerator", 4).toInt();
     int ts_div = settings.value("rhythmDenominator", 4).toInt();
+    m_style = settings.value("qtstyle", "fusion").toString();
+    m_darkMode = settings.value("darkMode", false).toBool();
+    m_internalIcons = settings.value("internalIcons", false).toBool();
     m_seq->setVolume(volume);
     m_seq->setBalance(balance);
     m_seq->setWeakVelocity(weakVel);
@@ -344,6 +361,9 @@ void KMetronome::optionsPreferences()
     dlg->fillOutputConnections(m_seq->outputConnections());
     dlg->fillInputConnections(m_seq->inputConnections());
     dlg->fillInstruments(m_instrumentList);
+    dlg->fillStyles();
+    dlg->setDarkMode(m_darkMode);
+    dlg->setInternalIcons(m_internalIcons);
     dlg->setAutoConnect(m_seq->getAutoConnect());
     QString conn = m_seq->getOutputConn();
     if (conn != nullptr && !conn.isEmpty())
@@ -381,6 +401,10 @@ void KMetronome::optionsPreferences()
             m_seq->connect_input();
             m_seq->sendInitialControls();
         }
+        m_style = dlg->getStyle();
+        m_darkMode = dlg->getDarkMode();
+        m_internalIcons = dlg->getInternalIcons();
+        applyVisualStyle();
     }
     delete dlg;
 }
@@ -515,6 +539,7 @@ void KMetronome::readDrumGridPattern()
         m_drumgrid->setSequencer(m_seq);
     }
     m_drumgrid->setInstrument(m_instrument);
+    m_drumgrid->setIcons(m_internalIcons);
     if (m_patternMode)
         m_drumgrid->readPattern(getSelectedPattern());
 }
@@ -594,7 +619,13 @@ void KMetronome::exportPatterns(const QString& path)
 
 void KMetronome::slotImportPatterns()
 {
-    QString dirName = QStandardPaths::locate(QStandardPaths::DataLocation, "*.pat", QStandardPaths::LocateDirectory) ;
+    QString dirName = QStandardPaths::locate(
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
+        QStandardPaths::DataLocation
+#else
+        QStandardPaths::AppLocalDataLocation
+#endif
+        , "*.pat", QStandardPaths::LocateDirectory);
     QString path = QFileDialog::getOpenFileName(this, tr("Import Patterns"),dirName,tr("Pattern Files (*.pat)"));
     if (!path.isEmpty()) {
         importPatterns(path);
@@ -603,7 +634,12 @@ void KMetronome::slotImportPatterns()
 
 void KMetronome::slotExportPatterns()
 {
-    QString dirName = QStandardPaths::writableLocation(QStandardPaths::DataLocation);
+    QString dirName = QStandardPaths::writableLocation(
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
+        QStandardPaths::DataLocation);
+#else
+        QStandardPaths::AppLocalDataLocation);
+#endif
     QDir dir(dirName);
     if (!dir.exists()) {
         dir.mkpath(dirName);
@@ -701,7 +737,6 @@ void KMetronome::setSelectedPattern(const QString& pattern)
     }
 }
 
-
 QString KMetronome::configuredLanguage()
 {
     if (m_language.isEmpty()) {
@@ -711,7 +746,7 @@ QString KMetronome::configuredLanguage()
         m_language = settings.value("language", defLang).toString();
         settings.endGroup();
     }
-    qDebug() << Q_FUNC_INFO << m_language;
+    //qDebug() << Q_FUNC_INFO << m_language;
     return m_language;
 }
 
@@ -747,7 +782,8 @@ void KMetronome::createLanguageMenu()
         QFileInfo f(it.next());
         QString locale = f.fileName();
         if (locale.startsWith("kmetronome_")) {
-            locale.remove(0, 11).truncate(locale.lastIndexOf('.'));
+            locale.remove(0, locale.indexOf('_') + 1);
+            locale.truncate(locale.lastIndexOf('.'));
             locales << locale;
         }
     }
@@ -768,6 +804,38 @@ void KMetronome::createLanguageMenu()
     }
 }
 
+void KMetronome::applyVisualStyle()
+{
+    //qDebug() << Q_FUNC_INFO << m_darkMode;
+    static QPalette light = qApp->palette();
+    static QPalette dark(QColor(0x30,0x30,0x30));
+    qApp->setPalette( m_darkMode ? dark : light );
+    qApp->setStyle( m_style );
+    refreshIcons();
+    m_ui.m_measureLCD->loadRenderer();
+    m_ui.m_tempoLCD->loadRenderer();
+    m_ui.m_measureLCD->update();
+    m_ui.m_tempoLCD->update();
+}
+
+void KMetronome::refreshIcons()
+{
+    m_ui.actionImportPatterns->setIcon(IconUtils::GetIcon("document-import", m_internalIcons));
+    m_ui.actionExportPatterns->setIcon(IconUtils::GetIcon("document-export", m_internalIcons));
+    m_ui.actionPlayStop->setIcon(IconUtils::GetIcon("media-playback-start", m_internalIcons));
+    m_ui.actionEditPatterns->setIcon(IconUtils::GetIcon("document-edit", m_internalIcons));
+    m_ui.actionConfiguration->setIcon(IconUtils::GetIcon("configure", m_internalIcons));
+    m_ui.actionAbout->setIcon(IconUtils::GetIcon("midi/icon32", true));
+    m_ui.actionQuit->setIcon(IconUtils::GetIcon("application-exit", m_internalIcons));
+    m_ui.actionHelp->setIcon(IconUtils::GetIcon("help-contents", m_internalIcons));
+    m_ui.m_playbtn->setIcon(IconUtils::GetIcon("media-playback-start", m_internalIcons));
+    m_ui.m_stopbtn->setIcon(IconUtils::GetIcon("media-playback-stop", m_internalIcons));
+    m_ui.m_patternbtn->setIcon(IconUtils::GetIcon("document-edit", m_internalIcons));
+    m_ui.m_configbtn->setIcon(IconUtils::GetIcon("configure", m_internalIcons));
+    m_ui.m_exitbtn->setIcon(IconUtils::GetIcon("application-exit", m_internalIcons));
+    IconUtils::SetWindowIcon(this);
+}
+
 void KMetronome::retranslateUi()
 {
     QLocale locale(configuredLanguage());
@@ -779,6 +847,7 @@ void KMetronome::retranslateUi()
     }
     m_ui.retranslateUi(this);
     m_seq->retranslateUi();
+    m_helpWindow->retranslateUi();
     createLanguageMenu();
     updatePatterns();
 }
