@@ -1,6 +1,6 @@
 /***************************************************************************
  *   KMetronome - ALSA Sequencer based MIDI metronome                      *
- *   Copyright (C) 2005-2020 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
+ *   Copyright (C) 2005-2021 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -16,6 +16,8 @@
  *   along with this program. If not, see <http://www.gnu.org/licenses/>.*
  ***************************************************************************/
 
+#include <QStyle>
+#include <QStyleFactory>
 #include "kmetropreferences.h"
 #include "iconutils.h"
 
@@ -62,6 +64,19 @@ void KMetroPreferences::fillInstruments(InstrumentList* instruments)
     }
 }
 
+void KMetroPreferences::fillStyles()
+{
+    QStringList styleNames = QStyleFactory::keys();
+    m_ui.m_style->addItems(styleNames);
+    QString currentStyle = qApp->style()->objectName();
+    foreach(const QString& s, styleNames) {
+        if (QString::compare(s, currentStyle, Qt::CaseInsensitive) == 0) {
+            m_ui.m_style->setCurrentText(s);
+            break;
+        }
+    }
+}
+
 void KMetroPreferences::slotInstrumentChanged(int /*idx*/)
 {
     QString name = m_ui.m_instrument->currentText();
@@ -148,6 +163,11 @@ QString KMetroPreferences::getBankName()
     return m_ui.m_bank->currentText();
 }
 
+QString KMetroPreferences::getStyle()
+{
+    return m_ui.m_style->currentText();
+}
+
 void KMetroPreferences::setInstrumentName(QString name)
 {
     m_ui.m_instrument->setCurrentText(name);
