@@ -1,6 +1,6 @@
 /***************************************************************************
  *   KMetronome - ALSA Sequencer based MIDI metronome                      *
- *   Copyright (C) 2005-2014 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
+ *   Copyright (C) 2005-2021 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,10 +12,8 @@
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,            *
- *   MA 02110-1301, USA                                                    *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program. If not, see <http://www.gnu.org/licenses/>.*
  ***************************************************************************/
 
 #ifndef KMETROPREFERENCES_H
@@ -30,11 +28,12 @@ class KMetroPreferences : public QDialog
     Q_OBJECT
 
 public:
-    KMetroPreferences(QWidget *parent = 0);
+    KMetroPreferences(QWidget *parent = nullptr);
     virtual ~KMetroPreferences();
     void fillInputConnections(QStringList lst) { m_ui.m_in_connection->insertItems(0, lst); }
     void fillOutputConnections(QStringList lst) { m_ui.m_out_connection->insertItems(0, lst); }
     void fillInstruments(InstrumentList* instruments);
+    void fillStyles();
     bool getAutoConnect() { return m_ui.m_autoconn->isChecked(); }
     QString getOutputConnection() { return m_ui.m_out_connection->currentText(); }
     QString getInputConnection() { return m_ui.m_in_connection->currentText(); }
@@ -43,10 +42,13 @@ public:
     int getDuration() { return m_ui.m_duration->value(); }
     bool getSendNoteOff() { return m_ui.m_use_noteoff->isChecked(); }
     QString getInstrumentName();
-    QString  getProgramName();
-    QString  getBankName();
+    QString getProgramName();
+    QString getBankName();
+    QString getStyle();
     int getWeakNote();
     int getStrongNote();
+    bool getDarkMode() { return m_ui.m_dark_mode->isChecked(); }
+    bool getInternalIcons() { return m_ui.m_internal_icons->isChecked(); }
 
     void setAutoConnect(bool newValue) { m_ui.m_autoconn->setChecked(newValue); }
     void setOutputConnection(QString newValue);
@@ -60,6 +62,8 @@ public:
     void setInstrumentName(QString name);
     void setProgramName(QString name);
     void setBankName(QString name);
+    void setDarkMode(bool mode) { m_ui.m_dark_mode->setChecked(mode); }
+    void setInternalIcons(bool icons) { m_ui.m_internal_icons->setChecked(icons); }
 
 public slots:
     void slotInstrumentChanged(int idx);
