@@ -1,6 +1,6 @@
 /*
     KMetronome - ALSA Sequencer based MIDI metronome
-    Copyright (C) 2006-2014, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,9 +12,8 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef LCDNUMBERVIEW_H
@@ -29,16 +28,14 @@ class LCDNumberView : public QGraphicsView
 {
     Q_OBJECT
 public:
-    explicit LCDNumberView(QWidget *parent = 0);
+    explicit LCDNumberView(QWidget *parent = nullptr);
     QString number();
     int digitCount();
     void setDigitCount(const int count);
-
-protected:
     void loadRenderer();
-    void resizeEvent(QResizeEvent *event);
     void update();
     void rescale();
+    void resizeEvent(QResizeEvent *event) override;
 
 public slots:
     void setNumber(const QString& number);
