@@ -1,6 +1,6 @@
 /***************************************************************************
  *   KMetronome - ALSA Sequencer based MIDI metronome                      *
- *   Copyright (C) 2005-2014 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
+ *   Copyright (C) 2005-2021 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,23 +12,38 @@
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,            *
- *   MA 02110-1301, USA                                                    *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program. If not, see <http://www.gnu.org/licenses/>.*
  ***************************************************************************/
 
 #include <QApplication>
+#include <QCommandLineParser>
 #include "kmetronome.h"
-#include "defs.h"
 
 int main (int argc, char **argv)
 {
+    const QString QSTR_APPNAME("Drumstick Metronome");
+    const QString QSTR_DOMAIN("kmetronome.sourceforge.net");
+    const QString QSTR_DESCRIPTION("ALSA Sequencer based MIDI Metronome");
+    const QString QSTR_VERSION(QT_STRINGIFY(VERSION));
+
     QCoreApplication::setOrganizationName(QSTR_DOMAIN);
     QCoreApplication::setOrganizationDomain(QSTR_DOMAIN);
     QCoreApplication::setApplicationName(QSTR_APPNAME);
+    QCoreApplication::setApplicationVersion(QSTR_VERSION);
     QApplication app(argc, argv);
-    KMetronome *mainWin = new KMetronome;
-    mainWin->show();
+
+    QCommandLineParser parser;
+    parser.setApplicationDescription(QSTR_DESCRIPTION);
+    auto helpOption = parser.addHelpOption();
+    auto versionOption = parser.addVersionOption();
+    parser.process(app);
+
+    if (parser.isSet(versionOption) || parser.isSet(helpOption)) {
+        return 0;
+    }
+
+    KMetronome mainWin;
+    mainWin.show();
     return app.exec();
 }
